summaryrefslogtreecommitdiff
path: root/keyboards/keychron/s1/ansi/white/white.c
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/keychron/s1/ansi/white/white.c')
-rw-r--r--keyboards/keychron/s1/ansi/white/white.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/keyboards/keychron/s1/ansi/white/white.c b/keyboards/keychron/s1/ansi/white/white.c
index e41ba06401..b3a49ae9eb 100644
--- a/keyboards/keychron/s1/ansi/white/white.c
+++ b/keyboards/keychron/s1/ansi/white/white.c
@@ -20,8 +20,8 @@
// clang-format off
-const ckled2001_led PROGMEM g_ckled2001_leds[LED_MATRIX_LED_COUNT] = {
-/* Refer to CKLED2001 manual for these locations
+const snled27351_led_t PROGMEM g_snled27351_leds[LED_MATRIX_LED_COUNT] = {
+/* Refer to SNLED27351 manual for these locations
* driver
* | LED address
* | | */